package com.muyu.common.core.enums;

import lombok.Getter;

import java.util.Arrays;

/**
 * @Author: 胡杨
 * @Name: SysApiState
 * @Description: 接口调用字典
 * @CreatedDate: 2024/8/20 下午7:56
 * @FilePath: com.muyu.common.core.enums
 */

@Getter
public enum SysApiState {
    OFF("off", "开启"),
    ON("on", "停用");

    private final String code;
    private final String info;

    SysApiState(String code, String info) {
        this.code = code;
        this.info = info;
    }

    /**
     * 鉴别参数是否是启用状态
     * @param code 需鉴别参数
     * @return 如果存在返回结果turn,否则返回false
     */
    public static boolean isCode(String code){
        return Arrays.stream(values())
                .map(SysApiState::getCode)
                .anyMatch(c -> c.equals(code));
    }

    /**
     * 参数转换,从编码转换为名称
     * @param code 编码
     * @return 名称
     */
    public static String getInfoByCode(String code){
        return Arrays.stream(values())
                .filter(c -> c.getCode().equals(code))
                .findFirst()
                .map(SysApiState::getInfo)
                .orElse("-");
    }
}
