package com.muyu.common.core.enums;

import lombok.Getter;

import java.util.Arrays;

/**
 * @Author: 胡杨
 * @Name: SysCheckState
 * @Description: 审核状态字典
 * @CreatedDate: 2024/8/20 下午8:01
 * @FilePath: com.muyu.common.core.enums
 */

@Getter
public enum SysCheckState {
    UN("un", "未审核"),
    YES("yes", "审核通过"),
    NO("no", "审核驳回");

    private final String code;
    private final String info;

    SysCheckState(String code, String info) {
        this.code = code;
        this.info = info;
    }

    /**
     * 鉴别参数是否是枚举的值
     *
     * @param code 需鉴别参数
     * @return 如果存在返回结果turn, 否则返回false
     */
    public static boolean isCode(String code) {
        return Arrays.stream(values())
                .map(SysCheckState::getCode)
                .anyMatch(c -> c.equals(code));
    }

    /**
     * 参数转换,从编码转换为名称
     * @param code 编码
     * @return 名称
     */
    public static String getInfoByCode(String code){
        return Arrays.stream(values())
                .filter(c -> c.getCode().equals(code))
                .findFirst()
                .map(SysCheckState::getInfo)
                .orElse("-");
    }
}
