package com.muyu.common.core.enums;

import lombok.Getter;

import java.util.Arrays;

/**
 * @Author: 胡杨
 * @Name: SysDBType
 * @Description: 数据源类型字典
 * @CreatedDate: 2024/8/20 下午8:22
 * @FilePath: com.muyu.common.core.enums
 */

@Getter
public enum SysDBType {
    MYSQL("mysql", "Mysql数据库"),
    REDIS("redis", "Redis数据库"),
    ES("es", "Es数据库"),
    OTHER("other", "其他");

    private final String code;
    private final String info;

    SysDBType(String code, String info) {
        this.code = code;
        this.info = info;
    }

    /**
     * 鉴别参数是否是枚举的值
     *
     * @param code 需鉴别参数
     * @return 如果存在返回结果turn, 否则返回false
     */
    public static boolean isCode(String code) {
        return Arrays.stream(values())
                .map(SysDBType::getCode)
                .anyMatch(c -> c.equals(code));
    }

    public static SysDBType[] getValues(){
        return values();
    }

    /**
     * 参数转换,从编码转换为名称
     * @param code 编码
     * @return 名称
     */
    public static String getInfoByCode(String code){
        return Arrays.stream(values())
                .filter(c -> c.getCode().equals(code))
                .findFirst()
                .map(SysDBType::getInfo)
                .orElse("-");
    }
}
